Coverage for src/paperap/models/ui_settings/model.py: 100%

1"""

2----------------------------------------------------------------------------

3

4 METADATA:

5

6 File: ui_settings.py

7 Project: paperap

8 Created: 2025-03-04

9 Version: 0.0.5

10 Author: Jess Mann

11 Email: jess@jmann.me

12 Copyright (c) 2025 Jess Mann

13

14----------------------------------------------------------------------------

15

16 LAST MODIFIED:

17

18 2025-03-04 By Jess Mann

19

20"""

21

22 from __future__ import annotations

23

24 from typing import Any

25

26 from pydantic import Field

27

28 from paperap.models.abstract.model import StandardModel

29 from paperap.models.ui_settings.queryset import UISettingsQuerySet

30

31

32 class UISettings(StandardModel):

33 """

34 Represents UI settings in Paperless-NgX.

35 """

36

37 user: dict[str, Any] = Field(default_factory=dict)

38 settings: dict[str, Any]

39 permissions: list[str] = Field(default_factory=list)

40

41 class Meta(StandardModel.Meta):

42 queryset = UISettingsQuerySet